package hw1;

/**
 * A class that can be used for calculating the cost of shipping books.
 *
 * @author CS159 Professors
 * @version 1.0
 */
public class BookShippingCostCalculator {

    private static final double POUNDS_PER_BOOK = 2.20;
    private static final double COST_PER_PALLET = 85.00;
    private static final double COST_PER_POUND = 1.50;

    private static final int BOOKS_PER_PALLET = 36;


    /**
     * Determine whether a particular shipment size involves
     * a partial pallet.
     *
     * @param shipmentSize The size of the shipment
     * @return true if the shipment involves extras; false otherwise
     */
    public static boolean involvesPartialPallet(int shipmentSize) {
        return (shipmentSize > 0) && (shipmentSize % BOOKS_PER_PALLET) > 0;
    }

    // Starts (from Starts and Completions)
    /**
     * Determine the total number of pallets required for a
     * particular shipment.
     *
     * @param shipmentSize The size of the shipment
     * @return The number of pallets
     */
    public static int numberOfPallets(int shipmentSize) {
        // Early return
        if (shipmentSize <= 0) return 0;

        int partialPallets;
        partialPallets = 0;
        if (involvesPartialPallet(shipmentSize)) partialPallets = 1;

        return numberOfCompletePallets(shipmentSize) + partialPallets;
    }

    // Completions (from Starts and Completions)
    /**
     * Determine the number of complete pallets required for a
     * particular shipment size.
     *
     * @param shipmentSize The size of the shipment
     * @return The number of complete pallets
     */
    public static int numberOfCompletePallets(int shipmentSize) {
        // Early return
        if (shipmentSize <= 0) return 0;

        return (shipmentSize / BOOKS_PER_PALLET);
    }

    /**
     * Determine the cost for a particular shipment.
     *
     * @param shipmentSize The size of the shipment
     * @return The price
     */
    public static double cost(int shipmentSize) {
        // Early return
        if (shipmentSize <= 0) return 0.00;

        double result;

        result = numberOfPallets(shipmentSize) * COST_PER_PALLET
                + shipmentSize * COST_PER_POUND * POUNDS_PER_BOOK;

        return result;
    }

}
